@@ -1,8 +1,6 @@
 #ifndef IDEFINES_H
 # define IDEFINES_H
 
-#define _LARGEFILE64_SOURCE
-
 #include <config.h>
 
 /* #define DEBUG Don't even think defining it:) */
@@ -56,8 +54,8 @@
 #endif
   
 
+#include <gettext.h>
 #ifdef ENABLE_NLS
-# include <libintl.h>
 # define _(String) gettext (String) 
 #else
 # define _(String) (String) 
@@ -67,6 +65,10 @@
 # include <utime.h>
 #endif
 
+#ifdef WIN32
+# undef HAVE_UTIME
+#endif
+
 /* for open */
 #ifdef HAVE_SYS_TYPES_H
 # include <sys/types.h>
@@ -88,14 +90,6 @@
 # include <unistd.h>
 #endif
 
-#ifndef HAVE_FOPEN64
-# define fopen64 fopen
-#endif
-
-#ifndef HAVE_FSEEKO64
-# define fseeko64 fseeko
-#endif
-
 #ifndef HAVE_FSEEKO
 # define fseeko fseek
 #endif
@@ -104,16 +98,6 @@
  typedef long off_t;
 #endif
 
-#ifdef HAVE_STAT64
-#  define stat_st struct stat64
-#else
-# ifdef HAVE_STAT
-#  define stat_st struct stat
-#  define stat64 stat
-#  define lstat64 lstat
-# endif
-#endif
-
 /* defines */
 #define SALT_SIZE 20
 
