@@ -16,9 +16,10 @@
  *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: errors.c,v 1.1.1.1 2000/05/22 13:09:26 nmav Exp $ */
+/* $Id: errors.c,v 1.3 2002/05/29 11:07:43 nmav Exp $ */
 
 #include <stdio.h>
+#include <stdlib.h>
 
 extern int quiet;
 
@@ -34,6 +35,12 @@ void err_warn(char *errmsg)
 		fprintf(stderr, errmsg);
 }
 
+void err_info(char *errmsg)
+{
+	if (quiet == 0)
+		fprintf(stderr, errmsg);
+}
+
 void err_crit(char *errmsg)
 {
 	if (quiet <= 2)
