@@ -1,5 +1,5 @@
 /*
- *    Copyright (C) 1998,1999,2000,2001,2002 Nikos Mavroyanopoulos
+ *    Copyright (C) 1998,1999,2000,2001,2002,2003 Nikos Mavroyanopoulos
  *
  *    This program is free software; you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 
 /* Some functions that didn't fit elsewhere */
 
-/* $Id: extra.c,v 1.24 2002/10/02 07:26:20 nmav Exp $ */
+/* $Id: extra.c,v 1.25 2003/02/21 17:57:14 nmav Exp $ */
 
 #ifndef DEFINES_H
 #define DEFINES_H
@@ -44,7 +44,7 @@
 #endif
 
 static char rcsid[] =
-    "$Id: extra.c,v 1.24 2002/10/02 07:26:20 nmav Exp $";
+    "$Id: extra.c,v 1.25 2003/02/21 17:57:14 nmav Exp $";
 
 #ifndef NO_GETPASS
 	#define FREE_STR(x) \
@@ -409,10 +409,10 @@ int write_iv(FILE * filedes, void *IV, int ivsize)
 void copyDate(char *srcName, char *dstName)
 {
 	int retVal;
-	stat_st statBuf;
+	struct stat statBuf;
 	struct utimbuf uTimBuf;
 
-	retVal = stat64(srcName, &statBuf);
+	retVal = stat(srcName, &statBuf);
 	if (retVal == -1)
 		perror("stat");
 
@@ -428,13 +428,13 @@ void copyDate(char *srcName, char *dstName)
 
 int is_normal_file(char *filename)
 {
-	stat_st statBuf;
+	struct stat statBuf;
 
 #ifdef HAVE_LSTAT		/* Do not treat symlinks as regular files */
-	if (lstat64(filename, &statBuf) != 0)
+	if (lstat(filename, &statBuf) != 0)
 		return FALSE;
 #else
-	if (stat64(filename, &statBuf) != 0)
+	if (stat(filename, &statBuf) != 0)
 		return FALSE;
 #endif
 
@@ -619,9 +619,9 @@ unsigned char x;
 	} else {
 		FILE* fd;
 		
-		fd = fopen64( file, "rb");
+		fd = fopen( file, "rb");
 		if (fd == NULL) {
-		   perror("fopen64");
+		   perror("fopen");
 		   err_quit(_("Could not open file\n"));
 		}
 		x = getc( fd);
