@@ -8,68 +8,70 @@ typedef struct _gaainfo gaainfo;
 
 struct _gaainfo
 {
-#line 96 "mcrypt.gaa"
+#line 111 "mcrypt.gaa"
 	char **input;
-#line 95 "mcrypt.gaa"
+#line 110 "mcrypt.gaa"
 	int size;
-#line 86 "mcrypt.gaa"
-	char *hash;
-#line 82 "mcrypt.gaa"
-	char *mode;
-#line 77 "mcrypt.gaa"
-	char **keys;
-#line 76 "mcrypt.gaa"
-	int keylen;
-#line 73 "mcrypt.gaa"
-	char *algorithm;
-#line 70 "mcrypt.gaa"
-	char *config_file;
-#line 69 "mcrypt.gaa"
-	int config;
-#line 66 "mcrypt.gaa"
-	char *keyfile;
-#line 62 "mcrypt.gaa"
-	int unlink_flag;
-#line 59 "mcrypt.gaa"
-	char *kmode;
-#line 55 "mcrypt.gaa"
-	char *modes_directory;
-#line 52 "mcrypt.gaa"
-	char *algorithms_directory;
-#line 49 "mcrypt.gaa"
-	int keysize;
-#line 46 "mcrypt.gaa"
-	int ed_specified;
-#line 45 "mcrypt.gaa"
-	int ein;
-#line 44 "mcrypt.gaa"
-	int din;
-#line 41 "mcrypt.gaa"
-	int double_check;
-#line 38 "mcrypt.gaa"
-	int flush;
-#line 34 "mcrypt.gaa"
-	int nodelete;
-#line 31 "mcrypt.gaa"
-	int noiv;
-#line 28 "mcrypt.gaa"
-	int noecho;
-#line 25 "mcrypt.gaa"
-	int nolock;
-#line 22 "mcrypt.gaa"
-	int bzipflag;
-#line 19 "mcrypt.gaa"
-	int gzipflag;
-#line 16 "mcrypt.gaa"
-	int bare_flag;
-#line 13 "mcrypt.gaa"
-	int real_random_flag;
-#line 10 "mcrypt.gaa"
-	int force;
-#line 7 "mcrypt.gaa"
-	int timer;
-#line 3 "mcrypt.gaa"
+#line 100 "mcrypt.gaa"
 	int quiet;
+#line 92 "mcrypt.gaa"
+	int real_random_flag;
+#line 89 "mcrypt.gaa"
+	int noecho;
+#line 86 "mcrypt.gaa"
+	int force;
+#line 83 "mcrypt.gaa"
+	int timer;
+#line 79 "mcrypt.gaa"
+	int nodelete;
+#line 76 "mcrypt.gaa"
+	int unlink_flag;
+#line 73 "mcrypt.gaa"
+	int double_check;
+#line 70 "mcrypt.gaa"
+	int flush;
+#line 66 "mcrypt.gaa"
+	int bzipflag;
+#line 63 "mcrypt.gaa"
+	int gzipflag;
+#line 61 "mcrypt.gaa"
+	int bare_flag;
+#line 58 "mcrypt.gaa"
+	int noiv;
+#line 54 "mcrypt.gaa"
+	char **keys;
+#line 53 "mcrypt.gaa"
+	int keylen;
+#line 50 "mcrypt.gaa"
+	char *hash;
+#line 47 "mcrypt.gaa"
+	char *modes_directory;
+#line 44 "mcrypt.gaa"
+	char *mode;
+#line 41 "mcrypt.gaa"
+	char *algorithms_directory;
+#line 38 "mcrypt.gaa"
+	char *algorithm;
+#line 35 "mcrypt.gaa"
+	char *config_file;
+#line 34 "mcrypt.gaa"
+	int config;
+#line 31 "mcrypt.gaa"
+	char *keyfile;
+#line 28 "mcrypt.gaa"
+	char *kmode;
+#line 25 "mcrypt.gaa"
+	int keysize;
+#line 22 "mcrypt.gaa"
+	int ed_specified;
+#line 21 "mcrypt.gaa"
+	int ein;
+#line 20 "mcrypt.gaa"
+	int din;
+#line 16 "mcrypt.gaa"
+	int openpgp_z;
+#line 13 "mcrypt.gaa"
+	int openpgp;
 
 #line 114 "gaa.skel"
 };
