@@ -28,8 +28,14 @@
  * SUCH DAMAGE.
  */
 
+static char rcsid[] = "$Id: getpass.c,v 1.8 2002/05/29 11:07:43 nmav Exp $";
+
 /* stdout was replaced with stderr to fit in mcrypt 
- * Also /dev/(u)random is used for random numbers
+ * Also /dev/(u)random is used for random numbers.
+ *
+ * I like this getpass() because of the stars.. Not much people
+ * agree with me however, thus it is disabled by default :)
+ *
  * --Nikos
  */
 
@@ -57,7 +63,6 @@ return pass;
 
 extern int noecho;
 
-static char rcsid[] = "$Id: getpass.c,v 1.4 2001/09/16 18:16:39 nmav Exp $";
 
 /* new code, #undef if there are any problems...  */
 #ifdef HAVE_SIGLONGJMP
@@ -84,11 +89,12 @@ static RETSIGTYPE
 #define MAXLEN MAX_KEY_LEN
 
 char *
- readpass(FILE * fp)
+ readpass(FILE * fp, int star)
 {
 	static char asterix[MAXLEN + 1];
-        char *input=_secure_mcrypt_malloc(MAXLEN + 1);
-	char *cp, *ap, c;
+        static char input[MAXLEN + 1];
+	char *cp, c;
+	unsigned char *ap;
 	int i;
 
 	if (input==NULL) return NULL;
@@ -99,10 +105,6 @@ char *
 	cp = input;
 	ap = asterix;
 
-#ifdef HAVE_DEV_RANDOM
-	open_rand(0);		/* We do not need much randomness here */
-#endif
-
 	while (read(fileno(fp), &c, 1)) {
 		switch (c) {
 		case '\n':
@@ -120,16 +122,23 @@ char *
 				}
 			} else
 				putc('\a', stderr);	/* BEL */
+				
+			fflush(stderr);
 			break;
 		default:
 			*cp++ = c;
-#ifdef HAVE_DEV_RANDOM
-			*ap++ = (get_o_rand8() % 4) + 1;
-#else
-			*ap++ = (RAND8 % 4) + 1;
-#endif
-			for (i = 0; i < (*(ap - 1)); i++)
-				putc('*', stderr);
+
+			if (!star) {
+				mcrypt_randomize( ap, 1, 0);
+				*ap >>= 1;
+				*ap %= 5;
+				*ap = *ap + 2;
+				ap++;
+
+				for (i = 0; i < (*(ap - 1)); i++)
+					putc('*', stderr);
+				fflush(stderr);
+			}
 			break;
 		}
 		fflush(stderr);
@@ -138,39 +147,15 @@ char *
 	}
 
       endwhile:
-#ifdef HAVE_DEV_RANDOM
-	close_rand();		/* close /dev/urandom */
-#endif
-	*cp = 0;
+
+	putc('\r', stderr);
 	putc('\n', stderr);
 	fflush(stderr);
+	*cp = 0;
 	return input;
 
 }
 
-char *
- readpass_old(FILE * fp)
-{
-	char* input=_secure_mcrypt_malloc(MAXLEN + 1);
-	char *cp;
-
-	if (input==NULL) return NULL;
-	
-	fflush(stderr);
-	if (fgets(input, MAXLEN+1, fp) == input) {
-		if ((cp = strchr(input, '\n')))
-			*cp = '\0';
-		else
-			input[MAXLEN] = '\0';
-#ifdef USE_SGTTY
-		putc('\n', stderr);
-#endif
-		return input;
-
-	}
-	return NULL;
-}
-
 char *
  _mcrypt_getpass(const char *prompt)
 {
@@ -240,11 +225,7 @@ char *
 #ifdef USE_SGTTY
 	new_modes.sg_flags &= ~ECHO;
 #else
-  if (noecho==TRUE) {
-	new_modes.c_lflag &= ~(ECHO | ECHOE | ECHOK);
-  } else {
 	new_modes.c_lflag &= ~(ECHO | ECHOE | ECHOK | ICANON);
-  }
 	new_modes.c_lflag |= ECHONL;
 #endif
 
@@ -261,11 +242,8 @@ char *
 	if (fputs(prompt, stderr) == EOF)
 		goto out;
 
-      if (noecho==FALSE) {
-	return_value = readpass(fp);
-      } else {
-      	return_value = readpass_old(fp);
-      }
+        return_value = readpass(fp, noecho);
+
       out:
 	/*
 	 * the old SIGINT handler is restored after the tty
