@@ -19,7 +19,7 @@
  */
 
 
-/* $Id: mcrypt.c,v 1.35 2002/06/26 08:40:08 twoaday Exp $ */
+/* $Id: mcrypt.c,v 1.36 2002/12/18 11:37:27 nmav Exp $ */
 
 #ifndef DEFINES_H
 #define DEFINES_H
@@ -43,7 +43,7 @@
 #endif
 
 static char rcsid[] =
-    "$Id: mcrypt.c,v 1.35 2002/06/26 08:40:08 twoaday Exp $";
+    "$Id: mcrypt.c,v 1.36 2002/12/18 11:37:27 nmav Exp $";
 
 char tmperr[128];
 unsigned int stream_flag = FALSE;
@@ -135,7 +135,7 @@ void mcrypt_version()
    fprintf(stderr, _("Mcrypt v.%s (%s-%s-%s)\n"), VERSION, T_CPU,
 	   T_VENDOR, T_OS);
    fprintf(stderr, _("Linked against libmcrypt v.%s\n"),
-	   LIBMCRYPT_VERSION);
+	   mcrypt_check_version(NULL));
    fprintf(stderr,
 	   _
 	   ("Copyright (C) 1998-2002 Nikos Mavroyanopoulos (nmav@gnutls.org)\n"));
