@@ -25,6 +25,7 @@
 
 #include <defines.h>
 #include <extra.h>
+#include <xmalloc.h>
 
 /* UFC optimized for 32 bit machines */
 
@@ -649,7 +650,7 @@ char *salt;
 	char *outbuf;
 	int i, s;
 
-	outbuf = malloc(14);
+	outbuf = _mcrypt_malloc(14);
 	outbuf[0] = salt[0];
 	outbuf[1] = salt[1] ? salt[1] : salt[0];
 
@@ -749,7 +750,7 @@ gen_crypt(void *keyword, int key_size, unsigned char *password,
 	memmove(keyword, enciph, key_size);
 
 	Bzero(enciph, 13);
-	free(enciph);
+	_mcrypt_free(enciph);
 
 	return 0;
 }
