@@ -8,7 +8,7 @@ void * _secure_mcrypt_calloc(size_t nmemb, size_t size);
 void * _secure_mcrypt_realloc(void *ptr, size_t size);
 void _mcrypt_free( void* ptr);
 void _secure_mcrypt_free( void* ptr, int size);
-
+char* _mcrypt_strdup( const char* str);
 #else
 
 # define _mcrypt_malloc malloc
@@ -19,5 +19,6 @@ void _secure_mcrypt_free( void* ptr, int size);
 # define _secure_mcrypt_realloc realloc
 # define _mcrypt_free free
 # define _secure_mcrypt_free(x,y) free(x)
+# define _mcrypt_strdup strdup
 
 #endif
